@@ -116,7 +116,11 @@ int wb_io_internal(struct wb_device *wb, struct dm_io_request *io_req,
 
 sector_t dm_devsize(struct dm_dev *dev)
 {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,11,0)
+	return bdev_nr_sectors(dev->bdev);
+#else
 	return i_size_read(dev->bdev->bd_inode) >> 9;
+#endif
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1964,7 +1968,7 @@ static void writeboost_status(struct dm_target *ti, status_type_t type,
 
 static struct target_type writeboost_target = {
 	.name = "writeboost",
-	.version = {2, 2, 17},
+	.version = {2, 2, 18},
 	.module = THIS_MODULE,
 	.map = writeboost_map,
 	.end_io = writeboost_end_io,
